# Copyright (c) 2014  Dave Love, University of Liverpool
# Copyright (c) 2018  Dave Love, University of Manchester
# MIT licence

# Use external Lua
%if 0%{?el8}%{?fedora}
%global extlua 1
%endif

Name:		likwid
Version:	4.3.4
Release:	1%{?dist}
Summary:	Lightweight performance tools
License:	GPLv3+
URL:		https://github.com/RRZE-HPC/likwid/
Source0:	http://ftp.fau.de/pub/likwid/likwid-%{version}.tar.gz
BuildRequires:  perl perl(Data::Dumper) perl(Text::Balanced)
%if 0%{?extlua}
BuildRequires:  lua-devel
%else
Provides:       bundled(lua) = 5.3
%endif
%if 0%{?el6}%{?el7}
# For avx512, in particular
BuildRequires:	devtoolset-6-gcc-gfortran devtoolset-6-binutils
%else
BuildRequires:	gcc-gfortran
%endif
ExclusiveArch:	x86_64


%description
Likwid is a simple to install and use toolsuite of command line applications
for performance oriented programmers. It works for Intel and AMD processors.

It consists of:
* likwid-topology:
    Print thread, cache and NUMA topology
* likwid-perfctr:
    Configure and read out hardware performance counters on Intel and AMD
    processors
* likwid-powermeter:
    Read out RAPL Energy information and get info about Turbo mode steps
* likwid-pin:
    Pin your threaded application (pthread, Intel and gcc OpenMP to dedicated
    processors)
* likwid-genTopoCfg:
    Dumps topology information to a file
* likwid-memsweeper:
    Sweep memory of NUMA domains and evict cachelines from last level cache

%package lib
Summary:	Shared libararies for %{name}

%description lib
Shared libararies for %{name}

%package devel
Summary:	Development files for %{name}
Requires:	%{name}-lib%{?_isa} = %{version}-%{release}

%description	devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q


%build
%if 0%{?el6}%{?el7}
. /opt/rh/devtoolset-6/enable
%endif
# not smp-safe
make PREFIX=%_prefix SHARED_LIBRARY=true Q= RPATHS= \
     FORTRAN_INTERFACE=true FC=gfortran FCFLAGS="%optflags" \
     LDFLAGS="%{?__global_ldflags}" INSTALLED_LIBPREFIX=%_libdir \
     %{?extlua:LUA_INCLUDE_DIR=%_includedir LUA_LIB_NAME=lua LUA_BIN=%_bindir LUA_LIB_DIR=%_libdir} #

%install
make install PREFIX=%buildroot%_prefix INSTALLED_PREFIX=%_prefix Q= \
     LIBPREFIX=%buildroot%_libdir INSTALLED_LIBPREFIX=%_libdir \
     INSTALL_CHOWN= MANPREFIX=%buildroot%_mandir \
     %{?extlua:LUA_INCLUDE_DIR=%_includedir} #
mkdir -p %buildroot%_datadir/cmake
mv %buildroot%_libdir/*cmake %buildroot%_datadir/cmake

%check
# Needs installation?
#make -C test Q= FC=gfortran FCFLAGS="%optflags"

%ldconfig_scriptlets

%files
%license COPYING
%doc README.md CHANGELOG
%_sbindir/likwid-accessD
%_sbindir/likwid-setFreq
%_bindir/*
%_mandir/man1/*
%exclude %_datadir/likwid/examples
%_datadir/likwid
%_datadir/lua/likwid.lua

%files lib
%license COPYING
# .so needed for Lua loading
%_libdir/*.so*

%files devel
%_includedir/*
%_datadir/likwid/examples
%dir %_datadir/cmake
%_datadir/cmake/likwid-config.cmake

%changelog
* Mon Jun 10 2019 Dave Love <loveshack@fedoraproject.org> - 4.3.4-1
- New version

* Fri Nov 30 2018 vagrant <vagrant@localhost.localdomain> - 4.3.3-1
- New version wth reorganization
- Maybe use external lua

* Thu Sep  8 2016 Dave Love <loveshack@fedoraproject.org> - 4.1.2-3
- Don't use %%dir %%_datadir/lua on el7

* Thu Sep  8 2016 Dave Love <loveshack@fedoraproject.org> - 4.1.2-2
- Provde bundled hwloc, lua

* Wed Sep  7 2016 Dave Love <loveshack@fedoraproject.org> - 4.1.2-1
- New version

* Thu Oct 15 2015 Dave Love <loveshack@fedoraproject.org> - 4.0.1-1
- New version
- Change patch, URL

* Tue Mar 17 2015 Dave Love <d.love@liverpool.ac.uk> - 3.1.3-1
- New version
- Modify patch

* Mon Jul  7 2014 Dave Love <d.love@liverpool.ac.uk> - 3.1.2-1
- Initial packaging
